require 'spec_helper'

RSpec.describe CorrelationId::Middleware::Faraday do
  let(:conn) do
    Faraday.new 'http://example.com' do |faraday|
      faraday.request :correlation_id
      faraday.adapter Faraday.default_adapter
    end
  end

  describe 'X-Correlation-ID' do
    let(:request) do
      a_request(:get, 'http://example.com/').with(headers: { 'X-Correlation-ID' => uuid })
    end

    let!(:response) do
      CorrelationId.uuid = uuid

      stub_request(:get, 'http://example.com/')
        .with(headers: { 'X-Correlation-ID' => uuid })
        .to_return(status: 200, headers: { 'X-Correlation-ID' => uuid })

      conn.get('/')
    end

    it 'sets header' do
      expect(request).to have_been_made.once
      expect(response.headers['X-Correlation-ID']).to eq(uuid)
    end
  end
end
