require 'spec_helper'

RSpec.describe CorrelationId do
  it 'has a version number' do
    expect(described_class::VERSION).not_to be nil
  end

  describe '.uuid' do
    def subject
      described_class.uuid
    end

    it 'generates uuid' do
      expect(subject).to be
    end

    it 'generates same id for one request' do
      expect(Array.new(5) { subject }.uniq).to be_one
    end
  end

  describe '.uuid!' do
    def subject
      described_class.uuid!
    end

    it 'generates uuid' do
      expect(subject).to be
    end

    it 'generates new id for each request' do
      expect(Array.new(5) { subject }.uniq.length).to eq(5)
    end

    it 'stores uuid' do
      generated = subject
      retrieved = described_class.uuid

      expect(generated).to eq(retrieved)
    end
  end

  describe '.uuid=' do
    let(:uuid) { SecureRandom.uuid }

    before { described_class.uuid = uuid }

    it 'sets uuid' do
      expect(described_class.uuid).to eq(uuid)
    end
  end

  describe '.disable' do
    let(:uuid) { SecureRandom.uuid }

    before { described_class.uuid = uuid }

    it 'can be temporarily disable' do
      expect(described_class.uuid).to eq(uuid)

      described_class.disable do
        expect(described_class.uuid).to be
        expect(described_class.uuid).not_to eq(uuid)
      end

      expect(described_class.uuid).to eq(uuid)
    end
  end
end
